/*  TAB P   VER 046   $Id: tune.h,v 1.9 1999/04/05 19:01:51 src Exp $
 *
 *  configuration
 *  tune as required
 *
 *  copyright 1996, 1997, 1998 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: tune.h,v $
 *  Revision 1.9  1999/04/05 19:01:51  src
 *  Lock for scanlogs
 *
 *  Revision 1.8  1998/09/09 07:32:15  src
 *  Version 1.1
 *
 *  Revision 1.7  1998/07/12 09:39:31  src
 *  newsx version 1.0
 */

/*
 *  default timeouts
 */
#ifndef TIMEOUT
#  define TIMEOUT   600     /* for TCP/IP read: 10 minutes */
#endif
#ifndef CONNTIME
#  define CONNTIME TIMEOUT  /* for TCP/IP connect, 0 to disable */
#endif
#ifndef LOCKTIME
#  define LOCKTIME TIMEOUT  /* for lockfile */
#endif
#ifndef SCANLOGTIME
#  define SCANLOGTIME (3*TIMEOUT) /* for scanlogs lockfile */
#endif

#ifndef LOCKDELTA
#  define LOCKDELTA  5      /* poll cycle: 5 seconds */
#endif
#define URGENT_TIMEOUT 1    /* when an error already has happened */

/*
 *  maximum window size
 */
#define REQ_MAX 1000

/*
 *  guideline for size of incoming spool
 */
#ifndef MINSPOOL
#  define MINSPOOL 100000   /* default to 100 kbytes */
#endif

/*
 *  never use force when unlocking
 */
/* #define NO_FORCE */
